C
C
C     ****************************************************************
C
      SUBROUTINE COVSRT(COVAR,NCVM,MA,LISTA,MFIT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)  
* Used by MRQMIN
* H.Press et al - NUMERICAL RECEPIES, Cambridge UP 86, page 515
*
      dimension COVAR(NCVM,NCVM)
      dimension LISTA(MFIT)
*
      DO  12  J=1,MA-1
        DO  11  I = J+1, MA
          COVAR(I,J) = 0.0
11      CONTINUE
12    CONTINUE
*
      DO  14  I = 1, MFIT-1
        DO  13  J = I+1, MFIT
c          IF( LISTA(J) .GT. LISTA(I) ) THEN
c            COVAR(LISTA(J),LISTA(I)) = COVAR(I,J)
           if( j.gt.i) then
              covar( j,i ) =covar( i,j )
          ELSE
c            COVAR(LISTA(I),LISTA(J)) = COVAR(I,J)
             covar( i, j ) = covar ( i, j )
          ENDIF
13      CONTINUE
14    CONTINUE
*
      SWAP = COVAR(1,1)
      DO  15  J=1,MA
        COVAR(1,J) = COVAR(J,J)
        COVAR(J,J) = 0.0
15    CONTINUE
*
c      COVAR(LISTA(1),LISTA(1)) = SWAP
       covar( 1 ,1 ) =swap
c
      DO  16  J = 2, MFIT
c        COVAR(LISTA(J),LISTA(J)) = COVAR(1,J)
          covar( j, j ) =covar( 1, j )

16    CONTINUE
      DO  18  J = 2, MA
        DO  17  I = 1, J-1
          COVAR(I,J) = COVAR(J,I)
17      CONTINUE
18    CONTINUE
      END
